This function updates the clusters and the initial tree in the lists data and config
pre_clustering(data, config)A named list containing two components $data and
$config. data data items as returned by outbreaker_data.
config is a list of settings as returned by create_config.
A list of data items as returned by outbreaker_data, or
arguments passed to this function.
A list of settings as returned by create_config, or
arguments passed to this function.
Alexis Robert (alexis.robert@lshtm.ac.uk)